<?php
/**
 * alpha-blog functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package alpha-blog
 */


if ( ! function_exists( 'alpha_blog_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function alpha_blog_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on alpha-blog, use a find and replace
		 * to change 'alpha-blog' to the name of your theme in all the template files.
		 */

		load_theme_textdomain( 'alpha-blog', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
        
        add_image_size( 'alpha-blog-thumbnail-one', 800, 450, true ); //Blog Thumbnail
        add_image_size( 'alpha-blog-thumbnail-two', 300, 300, true ); //Author Widget Thumbnail

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'alpha-blog' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'alpha_blog_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
        
        // Add post-formats for theme
        add_theme_support( 'post-formats', array(
            'audio',
            'video',
            'quote',
            'gallery',
            'link'
        ) );
        
        // Add support for gutenberg
		add_theme_support( 'align-wide' );
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'responsive-embeds' );
        
        // WooCommerce support
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
        add_theme_support( 'wc-product-gallery-lightbox' );
        add_theme_support( 'wc-product-gallery-slider' );
	}
endif;
add_action( 'after_setup_theme', 'alpha_blog_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function alpha_blog_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.Naminaponventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'alpha_blog_content_width', 640 );
}
add_action( 'after_setup_theme', 'alpha_blog_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function alpha_blog_widgets_init() {
    
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'alpha-blog' ),
		'id'            => 'alpha-blog-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'alpha-blog' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	) );
    
    register_sidebar(
		array(
			'name'          => esc_html__( 'Shop Sidebar', 'alpha-blog' ),
			'id'            => 'alpha-blog-sidebar-shop',
			'description'   => esc_html__( 'Add widgets here.', 'alpha-blog' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="widget-title"><h3>',
			'after_title'   => '</h3></div>',
		)
	);
    
   
    
    register_sidebar( array(
		'name'          => esc_html__( 'Top Widget Area', 'alpha-blog' ),
		'id'            => 'alpha-blog-top-widget',
		'description'   => esc_html__( 'Widgets here are shown below site banner and above blog page.', 'alpha-blog' ),
		'before_widget' => '<div class="widget text_widget">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	) );
    
    register_sidebar( array(
		'name'          => esc_html__( 'Bottom Widget Area', 'alpha-blog' ),
		'id'            => 'alpha-blog-bottom-widget',
		'description'   => esc_html__( 'Widgets here are shown below blog page and above site footer.', 'alpha-blog' ),
		'before_widget' => '<div class="widget text_widget">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	) );
    
    register_sidebar( array(
		'name'          => esc_html__( 'Footer Left', 'alpha-blog' ),
		'id'            => 'alpha-blog-footer-left',
		'description'   => esc_html__( 'Add widgets here.', 'alpha-blog' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	) );
    
    register_sidebar( array(
		'name'          => esc_html__( 'Footer Middle', 'alpha-blog' ),
		'id'            => 'alpha-blog-footer-middle',
		'description'   => esc_html__( 'Add widgets here.', 'alpha-blog' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	) );
    
    register_sidebar( array(
		'name'          => esc_html__( 'Footer Right', 'alpha-blog' ),
		'id'            => 'alpha-blog-footer-right',
		'description'   => esc_html__( 'Add widgets here.', 'alpha-blog' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	) );
    
    register_widget( 'alpha_Blog_Author_Widget' );
    
    register_widget( 'alpha_Blog_Social_Widget' );
    
    register_widget( 'alpha_Blog_Post_Widget' );
    
}
add_action( 'widgets_init', 'alpha_blog_widgets_init' );

/**
 * Enqueue supplemental block editor styles.
 */
function alphablog_block_editor_styles() {

	$css_dependencies = array();

	// Enqueue the editor styles.
	wp_enqueue_style( 'alphablog-block-editor-styles', get_theme_file_uri( '/alpha/assets/dist/css/editor-style-block.css' ), $css_dependencies, wp_get_theme()->get( 'Version' ), 'all' );
	wp_style_add_data( 'alphablog-block-editor-styles', 'rtl', 'replace' );

	// Add inline style from the Customizer.
	wp_add_inline_style( 'alphablog-block-editor-styles', alphablog_get_customizer_css( 'block-editor' ) );

	// Add inline style for non-latin fonts.
	wp_add_inline_style( 'alphablog-block-editor-styles', alphablog_Non_Latin_Languages::get_non_latin_css( 'block-editor' ) );

	// Enqueue the editor script.
	wp_enqueue_script( 'alphablog-block-editor-script', get_theme_file_uri( '/alpha/assets/src/js/custom/editor-script-block.js' ), array( 'wp-blocks', 'wp-dom' ), wp_get_theme()->get( 'Version' ), true );
}

add_action( 'enqueue_block_editor_assets', 'alphablog_block_editor_styles', 1, 1 );

/**
 * Enqueue classic editor styles.
 */
function alphablog_classic_editor_styles() {

	$classic_editor_styles = array(
		'/alpha/assets/dist/css/editor-style-classic.css',
	);

	add_editor_style( $classic_editor_styles );

}

add_action( 'init', 'alphablog_classic_editor_styles' );

/**
 * Enqueue scripts and styles.
 */

function alpha_blog_admin_styles() {

  	wp_enqueue_style('alpha-blog-ap-admin-style', get_template_directory_uri().'/alpha/admin/css/ap-admin-style.css');
}
add_action('admin_enqueue_scripts', 'alpha_blog_admin_styles');


function alpha_blog_scripts() {
    
	wp_enqueue_style( 'alpha-blog-style', get_stylesheet_uri() );
    
    wp_enqueue_style( 'alpha-blog-google-fonts', alpha_blog_fonts_url() );
    
	wp_enqueue_style( 'alpha-blog-main', get_template_directory_uri() . '/alpha/assets/dist/css/main-style.css' );
    
    wp_enqueue_style( 'alpha-blog-woocommerce-style', get_template_directory_uri() . '/alpha/woocommerce/woocommerce.css' );
    
    if( ! is_singular() ) {

        global $wp_query;

        wp_register_script( 'alpha-blog-ajax-script', get_template_directory_uri() . '/alpha/assets/dist/js/ajax-script.js', array( 'jquery' ), wp_get_theme()->get( 'Version' ), true );

        wp_localize_script( 'alpha-blog-ajax-script', 'alpha_blog_obj', array(

            'ajaxurl' => site_url() . '/wp-admin/admin-ajax.php',
            'posts' => json_encode( $wp_query->query_vars ),
            'current_page' => $wp_query->query_vars['paged'] ? $wp_query->query_vars['paged'] : 1,
            'max_page' => $wp_query->max_num_pages,
            'first_page' => get_pagenum_link(1)
        ) );

        wp_enqueue_script( 'alpha-blog-ajax-script' );
    }

    wp_enqueue_script( 'alpha-blog-bundle', get_template_directory_uri() . '/alpha/assets/dist/js/bundle.min.js', array( 'jquery' ), wp_get_theme()->get( 'Version' ), true );

	wp_enqueue_script( 'alpha-blog-navigation', get_template_directory_uri() . '/alpha/assets/src/js/libraries/navigation.js', array(), wp_get_theme()->get( 'Version' ), true );

	wp_enqueue_script( 'alpha-blog-skip-link-focus-fix', get_template_directory_uri() . '/alpha/assets/src/js/libraries/skip-link-focus-fix.js', array(), wp_get_theme()->get( 'Version' ), true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'alpha_blog_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/theme-functions.php';

/**
 * Extras function for this theme.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Post Meta Sidebar Position for this theme.
 */
require get_template_directory() . '/inc/custom-fields/sidebar-position.php';

/**
 * Load breadcrumbs.
 */
require get_template_directory() . '/third-party/breadcrumbs.php';




/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load Author Widget.
 */
require get_template_directory() . '/widgets/author-widget.php';

/**
 * Load Social Widget One.
 */
require get_template_directory() . '/widgets/social-widget.php';

/**
 * Load Post Widget.
 */
require get_template_directory() . '/widgets/post-widget.php';

if ( class_exists( 'WooCommerce' ) ) {
	/**
	 * WooCommerce functions.
	 */
	require get_template_directory() . '/inc/woocommerce-functions.php';
}
